<?php

namespace Kylin\Export\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * 导出任务模型
 *
 * 记录数据导出任务，包括类型、文件名、状态、行数、
 * 导出路径、过滤条件等信息。
 */
class Export extends Model
{
    protected $table = 'kylin_exports';

    protected $fillable = [
        'type', 'filename', 'status', 'rows', 'path', 'error', 'filters', 'user_id',
    ];

    protected $casts = ['filters' => 'array'];
}
