<?php

declare(strict_types=1);

namespace Kylin\Export\Policies;

use Kylin\Rbac\Policies\CrudPolicy;

/**
 * 导出权限策略
 *
 * 继承 CrudPolicy，自动实现标准 CRUD 权限校验。
 * 权限命名：export.view、export.create、export.update、export.delete
 *
 * 依据等保 2.0 (GB/T 22239) 8.1.4.1：
 * 数据导出功能需进行访问控制。
 */
class ExportPolicy extends CrudPolicy
{
    protected string $resource = 'export';
}