<?php

use Illuminate\Support\Facades\Route;
use Kylin\Export\Http\Controllers\ExportController;

Route::prefix('kylin/exports')->middleware(['auth:sanctum'])->group(function () {
    Route::get('/', [ExportController::class, 'index']);
    Route::post('/', [ExportController::class, 'store']);
    Route::get('/{id}', [ExportController::class, 'show']);
    Route::get('/{id}/download', [ExportController::class, 'download']);
});
